This function calculates and reports base rate estimates for taxometric analysis.
CalculateBaseRates(x.results, parameters)This program returns nothing, and provides text output only.
Empirical data results
The data and program parameters
John Ruscio <[email protected]> and Shirley Wang <[email protected]> Maintainer: John Ruscio <[email protected]>
Called by higher-order functions; users do not need to call this function directly.