Learn R Programming

RTaxometrics (version 3.2.1)

CreateVariable: Creates a variable

Description

Generates variable with g-and-h distribution.

Usage

CreateVariable(n, g, h, uniform)

Value

Single variable

Arguments

n

Size of sample to create

g

Parameter used to control asymmetry (scalar); sign indicates direction and absolute value indicates magnitude of skew (e.g., +/- .30 yields substantial asymmetry).

h

Parameter used to control tail weight (scalar); positive values yield tails that are longer/thinner than a standard normal curve, negative values do the reverse (e.g., +/- .15 is a substantial departure from normality).

uniform

Whether to generate random values (the program default) or use uniformly distributed quantiles (T/F).

Author

John Ruscio <[email protected]> and Shirley Wang <[email protected]> Maintainer: John Ruscio <[email protected]>

Details

Called by higher-order functions; users do not need to call this function directly.